@@ -1,4 +1,5 @@
-import os
+import json
+import pathlib
 
 import pytest
 from web3 import HTTPProvider, Web3
@@ -29,3 +30,12 @@ def consumer_account():
 @pytest.fixture
 def web3_instance():
     return Web3(HTTPProvider(get_keeper_url()))
+
+@pytest.fixture
+def external_contract():
+    name = 'ERC721'
+    address = '0x18bdFAf7Cc2B66a4Cfa7e069693CD1a9B639A69b'
+
+    with pathlib.Path(__file__).parent / 'resources/data/ERC721.json' as p:
+        abi = json.loads(p.read_text())['abi']
+        return (address, abi, name)
\ No newline at end of file
